@@ -410,6 +410,8 @@ class Device:
         self.largestReg = 1
         self.configs = {}
         self.defaults = {}
+        self.nextAddr = 0
+        self.storageSize = 0
 
     def addReg(self, reg):
         reg.device = self
@@ -547,9 +549,7 @@ class Device:
             regs = yamlNormalizeNodes( objDevice['registers'], 'reg_name','addr')
             for regItem in regs:
                 newReg = DeviceReg(regItem['reg_name'])
-
-                if 'addr' in regItem:
-                    newReg.addr = regItem['addr'] #int(regItem['addr'],0) 
+                
                 if 'type' in regItem:
                     newReg.type = regItem['type'].replace("_t","")
                     newReg.size = sizeDict[newReg.type.replace("_t","")]
@@ -564,7 +564,16 @@ class Device:
                 if 'default' in regItem:
                     newReg.default = regItem['default']
                     newReg.hasDefault = True
+                
+                
+                if 'addr' in regItem:
+                    newReg.addr = regItem['addr'] #int(regItem['addr'],0) 
+                else:
+                    newReg.addr = self.nextAddr
 
+                self.nextAddr = newReg.addr +  newReg.size
+
+                self.storageSize += newReg.size
                 self.addReg(newReg)      
         
         if 'fields' in objDevice:
